#ifndef CapStrings_H
#define CapStrings_H

/* A set of procedures for string manipulation.

   Copyright 1991, 1992  Capilano Computing Systems Ltd.
   All rights reserved.

   By Chris Dewhurst
   
   Modifications
   
   1/30/90	Changed StringError to a function
   3/30/91	Added max string size parameters
   6/22/92	Added routine CapComparePattern
   5/29/93 Cap	Added routine CapCompareName
*/

#include <Carbon/Carbon.h>

//#include "CapSys.h"	/* Defines which system/compiler we're running on */

#ifdef __cplusplus
extern "C" {
#endif


 Boolean CapStringError();


 short CapLength(const char *str, short strSize);


 void CapAssign(const char *source, short srcSize, char *dest, short dstSize);


 void CapInsert(const char *srcStr, short srcSize, char *dstStr, short dstSize, short insPos);


 void CapDelete(char *str, short size, short delPos, short len);

 short CapPos(const char *subStr, short subSize, const char *str, short strSize);


 void CapCopy(const char *str, short fromPos, short len,  char *dstStr, short dstSize);


/* Append the src string to the destination */

 void CapAppend(const char *src, short srcSize, char *dst, short dstSize);



/* "CapCompare" returns the following integers:

        0 if S1 is identical to S2
       -1 if S1 is lexically < S2
        1 if S1 is lexically > S2
*/
 short CapCompare(const char *s1, short s1Size, const char *s2, short s2Size);



/* "EqualStr" returns TRUE is s1 is identical to s2.  If "caseSensitive"
   is FALSE then the case of alphabetic characters in either string
   is ignored */

 Boolean CapEqualStr(const char *s1, short s1Size, const char *s2, short s2Size, Boolean caseSensitive);


/* "CapDec2Bin" scans the input string for a signed decimal number
   and converts it to binary.  Leading and trailing blanks are ignored.
   Conversion terminates and "stringError" is set on any
   non-numeric character, but the result will still be
   correct up to that point.   Overflow is not checked. */

 short CapDec2Bin( char *inStr, short inSize);

 long CapDec2BinLong( char *inStr, short inSize);

 void CapBin2Dec(short int_, Boolean leadZeroes, char *str, short strSize);

 void CapBin2DecLong(long int_, Boolean leadZeroes, char *str, short strSize);


/* "Verify" returns the position of the first character in "str1" that
   is not present in "str2".  E.g. Verify(string,"0123456789") returns
   the position of the first non-numeric character in "string".  If "str1"
   contains no characters not in "str2" then "Verify" returns the
   length of "str1" (i.e. a position past the end */

 short CapVerify(const char *s1, short s1Size, const char *s2, short s2Size);


 void CapMod2Pas(const char *m, short mSize, char *p, short pSize);


 void CapPas2Mod(const char *p, char *m, short mSize);


/* "CapSplitName" looks for a decimal number in the text string given,
   starting from the end of the string, and splits the string
   into three parts: the characters before the number, the characters
   after the number, and the number, returned as an integer.
   If no numeric chars are found, "begin" will be empty, "num" will
   be zero, and "end" will be equal to the input string. */

 void CapSplitName(const char *str, short strSize,
							char *begin, short beginSize,
							char *end, short endSize,
							short *num, short *numWidth
						    );


/* "IncName" looks for a decimal number in the text string given,
   starting from the end of the string, and adds the given
   increment value to it.  The increment must be between -9 and 9.
   If no digit is found in the name, the digit "1" is appended. */

 void CapIncName(char *str, short strSize,  short inc, Boolean leading);


/* "CapConcat" concatenates the two source strings and
   places the result in the destination string */

 void CapConcat(const char *s1, short s1Size, const char *s2, short s2Size, char *dstStr, short dstSize);



/* "CapComparePattern" compares the pattern string with the
   given string.  The pattern string may contain the following
   "wild card" characters:
   
   	*	matches any sequence of zero or more characters
	?	matches any single character
	#	matches any numeric character
   
   If "caseSensitive" is TRUE then alphabetic characters must
   be the same case to match, otherwise case is ignored. */

 Boolean CapComparePattern(	const char	*pattern,
										short		patSize,
										const char	*string, 
										short		strSize,
										Boolean		caseSensitive
									);




/* Compares strings "name1" and "name2", comparing alphabetic parts
   lexically and numeric parts numerically.  Thus, for example, the
   string "X12" will be greater than "X2", whereas in a purely lexical
   comparison it would be less than.  Returns:

        -1 if name1 < name2
         0 if name1 = name2
        +1 if name1 > name2
 */

 short CapCompareName( const char	*name1,
								short		name1Size,
								const char	*name2,
								short		name2Size,
								Boolean		caseSensitive
							   );



 void CapString_Init(void);

#ifdef __cplusplus
}
#endif
#endif /*CapStrings_H*/

 
